# Default provider build options (MySQL, Postgres, unixODBC, LDAP, FreeTDS)
#
# Package build options:
# --without mdb
# --without mysql
# --without postgres
# --without java
#

%define           MDB      1
%define           MYSQL    1
%define           POSTGRES 1
%define           JAVA     1

%{?_without_mdb:%define MDB     0}
%{?_without_mysql:%define MYSQL 0}
%{?_without_postgres:%define POSTGRES 0}
%{?_with_java:%define JAVA 1}

Name:             libgda
Epoch:            1
Version:          4.2.5
Release:          1%{?dist}
Summary:          Library for writing gnome database programs
Group:            System Environment/Libraries
License:          LGPLv2+
URL:              http://www.gnome-db.org/
Source:           http://ftp.gnome.org/pub/GNOME/sources/%{name}/4.0/%{name}-%{version}.tar.bz2
Patch1:           libgda-3.0.0-man.patch
Patch2:           libgda-3.99.8-lib64.patch
Patch3:           libgda-4.2.4-sqlite3.patch
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:    pkgconfig >= 0.8
BuildRequires:    glib2-devel >= 2.16
BuildRequires:	  gtk2-devel >= 2.20.0
BuildRequires:	  unique-devel >= 1.1.6
BuildRequires:	  gtksourceview2-devel >= 2.10.0
BuildRequires:	  goocanvas-devel >= 0.15
BuildRequires: 	  graphviz-devel >= 2.26.0
BuildRequires:	  iso-codes >= 3.15
BuildRequires:    libxslt-devel >= 1.0.9
BuildRequires:    sqlite-devel >= 3.6.0
BuildRequires:    gamin-devel >= 0.1.8
BuildRequires:    libtool
BuildRequires:    gobject-introspection-devel >= 0.6.5
BuildRequires:    libxml2-devel readline-devel db4-devel json-glib-devel
BuildRequires:    gtk-doc scrollkeeper intltool gettext flex bison perl(XML::Parser)
BuildRequires:    gnome-vfs2-devel >= 2.20
BuildRequires:    libsoup-devel
BuildRequires:	  java-1.6.0-openjdk >= 1.6.0.0
BuildRequires:    gnome-doc-utils
BuildRequires:	  db4-devel
# note we do not provide these, they no longer exist
Obsoletes:        %{name}-sharp < %{epoch}:%{version}-%{release}
Obsoletes:        %{name}-sharp-devel < %{epoch}:%{version}-%{release}

Obsoletes:        %{name}-freetds < %{epoch}:3.99.0
Obsoletes:        %{name}-freetds-devel < %{epoch}:3.99.0
Obsoletes:        %{name}-ldap < %{epoch}:3.99.0
Obsoletes:        %{name}-ldap-devel < %{epoch}:3.99.0
Obsoletes:        %{name}-odbc < %{epoch}:3.99.0
Obsoletes:        %{name}-odbc-devel < %{epoch}:3.99.0
Obsoletes:        %{name}-xbase < %{epoch}:3.99.0
Obsoletes:        %{name}-xbase-devel < %{epoch}:3.99.0


%if %{MYSQL}
BuildRequires:    mysql-devel
%endif

%if %{POSTGRES}
BuildRequires:    postgresql-devel
%endif

%if %{MDB}
BuildRequires:    mdbtools-devel
%endif

%if %{JAVA}
BuildRequires:    java-1.6.0-openjdk-devel
%endif

%description
libgda is a library that eases the task of writing
gnome database programs.


%package devel
Summary:          Development libraries and header files for libgda
Group:            Development/Libraries
Requires:         glib2-devel >= 2.0.0
Requires:         libxslt-devel >= 1.0.9
Requires:         db4-devel libxml2-devel pkgconfig
Requires:         %{name} = %{epoch}:%{version}-%{release}

%description devel
This package contains the header files and libraries needed to write
or compile programs that use libgda.

%package ui
Summary:          Libgda UI extensions
Group:            Development/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}

%description ui
libgda-ui extends libgda providing graphical widgets (Gtk+).

%package ui-devel
Summary:          Development libraries and header files for libgda-ui
Group:            Development/Libraries
Requires:         %{name}-ui = %{epoch}:%{version}-%{release}
Requires:         %{name}-devel = %{epoch}:%{version}-%{release}
Requires:	  gtk2-devel >= 2.20.0

%description ui-devel
This package contains the header files and libraries needed to write
or compile programs that use libgda-ui.

%package tools
Summary:	  Graphical tools for libgda
Group:		  Applications/Databases
Requires:	  %{name}-ui = %{epoch}:%{version}-%{release}

%description tools
This package provides libgda graphical tools.

%package sqlite
Summary:          SQLite provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
Requires:         sqlite%{?_isa} >= 3.6.O
Obsoletes:        gda-sqlite < %{epoch}:%{version}-%{release}
Provides:         gda-sqlite = %{epoch}:%{version}-%{release}
%description sqlite
This package includes the libgda SQLite provider.

%package sqlite-devel
Summary:          SQLite provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         pkgconfig
Requires:         %{name}-sqlite = %{epoch}:%{version}-%{release}
%description sqlite-devel
This package includes the pkgconfig file for the libgda SQLite provider.

%package sqlcipher
Summary:          SQLite provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
Obsoletes:        gda-sqlite < %{epoch}:%{version}-%{release}
Provides:         gda-sqlite = %{epoch}:%{version}-%{release}
%description sqlcipher
This package includes the libgda SQLCipher provider.

%package sqlcipher-devel
Summary:          SQLite provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         pkgconfig
Requires:         %{name}-sqlite = %{epoch}:%{version}-%{release}
%description sqlcipher-devel
This package includes the pkgconfig file for the libgda SQLCipher provider.

%package web
Summary:          Web provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
%description web
This package includes the libgda web provider.

%package web-devel
Summary:          Web provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         pkgconfig
Requires:         %{name}-web = %{epoch}:%{version}-%{release}
%description web-devel
This package includes the pkgconfig file for the libgda web provider.

%if %{MYSQL}
%package mysql
Summary:          MySQL provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
Obsoletes:        gda-mysql < %{epoch}:%{version}-%{release}
Provides:         gda-mysql = %{epoch}:%{version}-%{release}
%description mysql
This package includes the libgda MySQL provider.

%package mysql-devel
Summary:          MySQL provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         pkgconfig
Requires:         %{name}-mysql = %{epoch}:%{version}-%{release}
%description mysql-devel
This package includes the pkgconfig file for the libgda MySQL provider.
%endif

%if %{POSTGRES}
%package postgres
Summary:          PostgreSQL provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
Obsoletes:        gda-postgres < %{epoch}:%{version}-%{release}
Provides:         gda-postgres = %{epoch}:%{version}-%{release}
%description postgres
This package includes the libgda PostgreSQL provider.

%package postgres-devel
Summary:          PostgreSQL provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         pkgconfig
Requires:         %{name}-postgres = %{epoch}:%{version}-%{release}
%description postgres-devel
This package includes the pkgconfig file for the libgda PostgreSQL provider.
%endif

%if %{MDB}
%package mdb
Summary:          MDB provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
Obsoletes:        gda-mdb < %{epoch}:%{version}-%{release}
Provides:         gda-mdb = %{epoch}:%{version}-%{release}
%description mdb
This package includes the libgda MDB provider.

%package mdb-devel
Summary:          MDB provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         pkgconfig
Requires:         %{name}-mdb = %{epoch}:%{version}-%{release}
%description mdb-devel
This package includes the pkgconfig file for the libgda MDB provider.
%endif

%if %{JAVA}
%package java
Summary:          Java JDBC provider for libgda
Group:            System Environment/Libraries
Requires:         %{name} = %{epoch}:%{version}-%{release}
%description java
This package includes the GDA Java JDBC provider.

%package java-devel
Summary:          Java JDBC provider for libgda pkgconfig file
Group:            Development/Libraries
Requires:         %{name}-java = %{epoch}:%{version}-%{release}, pkgconfig
%description java-devel
This package includes the pkgconfig file for the libgda Java JDBC provider.
%endif


%prep
%setup -q
%patch1 -p1 -b .man
%patch2 -p1 -b .lib64
%patch3 -p1 -b .sqlite3
# need to reconfigure autotools scripts against newer toolchain
#autoreconf -fi


%build
CONFIG="--disable-static --disable-dependency-tracking --enable-system-sqlite --with-libsoup \
--enable-gtk-doc --enable-introspection=no \
--with-bdb=%{_prefix} --with-bdb-libdir-name=%{_lib}"

%if %{MYSQL}
CONFIG="$CONFIG --with-mysql"
%else
CONFIG="$CONFIG --without-mysql"
%endif

%if %{POSTGRES}
CONFIG="$CONFIG --with-postgres"
%else
CONFIG="$CONFIG --without-postgres"
%endif

%if %{MDB}
CONFIG="$CONFIG --with-mdb"
%else
CONFIG="$CONFIG --without-mdb"
%endif

%if %{JAVA}
CONFIG="$CONFIG --with-java"
%else
CONFIG="$CONFIG --without-java"
%endif

%configure $CONFIG
# Don't use rpath!
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
# workaround to fix linking failure for GI
export LD_LIBRARY_PATH=`pwd`/libgda/.libs:`pwd`/libgda-report/.libs:`pwd`/libgda-ui/.libs
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
# libgda/libgda.h is not installed ?
mv %{name}/%{name}.h $RPM_BUILD_ROOT/%{_includedir}/%{name}-4.0/%{name}/%{name}.h
# Cleanup unnecessary, unpackaged files
find $RPM_BUILD_ROOT -type f -name "*.la" -exec rm -f {} ';'
rm $RPM_BUILD_ROOT/%{_sysconfdir}/libgda-4.0/sales_test.db

%find_lang libgda-4.0


%post -p /sbin/ldconfig
%post ui -p /sbin/ldconfig

%post devel
if which scrollkeeper-update >/dev/null 2>&1; then scrollkeeper-update; fi

%postun -p /sbin/ldconfig
%postun ui -p /sbin/ldconfig

%postun devel
if which scrollkeeper-update >/dev/null 2>&1; then scrollkeeper-update; fi


%clean
rm -rf $RPM_BUILD_ROOT


%files -f libgda-4.0.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog README NEWS
%config(noreplace) %{_sysconfdir}/libgda-4.0
%{_bindir}/gda-list-*-4.0
%{_bindir}/gda-sql-4.0
%{_bindir}/gda-test-connection-4.0
%{_bindir}/gda_trml2*
%{_bindir}/gda-list-config
%{_bindir}/gda-list-server-op
%{_bindir}/gda-sql
%{_datadir}/libgda-4.0/dtd/libgda-*.dtd
%{_datadir}/%{name}-4.0/language-specs
%{_datadir}/%{name}-4.0/import_encodings.xml
%{_datadir}/%{name}-4.0/information_schema.xml
%{_libdir}/%{name}-4.0.so.*
%{_libdir}/%{name}-report-4.0.so.*
%{_libdir}/%{name}-xslt-4.0.so.*
%dir %{_libdir}/%{name}-4.0
%dir %{_libdir}/%{name}-4.0/providers
# note this file really should be in its own subpackage too, but libgda
# needs to have atleast one provider present to be of any use.
%{_libdir}/libgda-4.0/providers/libgda-bdb.so
%{_datadir}/%{name}-4.0/bdb_specs*.xml
#%{_libdir}/girepository-1.0/Gda-4.0.typelib
%{_mandir}/man1/*

%files devel
%defattr(-,root,root,-)
%doc %{_datadir}/gtk-doc/html/libgda-4.0
%{_includedir}/%{name}-4.0/%{name}/*
%{_includedir}/%{name}-4.0/%{name}-report/*
%{_includedir}/%{name}-4.0/%{name}-xslt/*
%{_libdir}/%{name}-4.0.so
%{_libdir}/%{name}-report-4.0.so
%{_libdir}/%{name}-xslt-4.0.so
%{_libdir}/pkgconfig/libgda-4.0.pc
%{_libdir}/pkgconfig/libgda-bdb-4.0.pc
%{_libdir}/pkgconfig/libgda-report-4.0.pc
%{_libdir}/pkgconfig/libgda-xslt-4.0.pc
#%{_datadir}/gir-1.0/Gda-4.0.gir

%files ui
%defattr(-,root,root,-)
%{_libdir}/%{name}-ui-4.0.so.*
%dir %{_libdir}/%{name}-4.0/plugins
%{_libdir}/%{name}-4.0/plugins/gdaui-*.xml
%{_libdir}/%{name}-4.0/plugins/libgda-ui-plugins.so
%{_datadir}/libgda-4.0/dtd/gdaui-layout.dtd
%{_datadir}/%{name}-4.0/server_operation.glade
%{_datadir}/%{name}-4.0/ui/gdaui-*.xml
#%{_libdir}/girepository-1.0/Gdaui-4.0.typelib
%{_datadir}/%{name}-4.0/pixmaps/gdaui-generic.png

%files ui-devel
%defattr(-,root,root,-)
%{_bindir}/gdaui-demo-4.0
%{_includedir}/%{name}-4.0/%{name}-ui/*
%{_libdir}/%{name}-ui-4.0.so
%{_libdir}/pkgconfig/%{name}-ui-4.0.pc
# most of samples here requires libgda-ui
%{_datadir}/%{name}-4.0/demo/*
%{_datadir}/%{name}-4.0/pixmaps/bin-attachment-16x16.png
#%{_datadir}/gir-1.0/Gdaui-4.0.gir

%files tools
%defattr(-,root,root,-)
%doc %{_datadir}/gtk-doc/html/gda-browser
%{_bindir}/gda-browser-4.0
%{_bindir}/gda-control-center-4.0
%{_datadir}/applications/gda-browser-4.0.desktop
%{_datadir}/applications/gda-control-center-4.0.desktop
%{_datadir}/%{name}-4.0/icons/hicolor/*
%{_datadir}/%{name}-4.0/pixmaps/gda-browser*.png
%{_datadir}/%{name}-4.0/pixmaps/gda-control-center*.png
%{_datadir}/icons/hicolor/*/apps/gda-control-center.png
%{_datadir}/gnome/help/gda-browser/*
%{_datadir}/pixmaps/gda-browser-4.0.png

%files sqlite
%defattr(-,root,root,-)
%{_libdir}/%{name}-4.0/providers/%{name}-sqlite.so
%{_datadir}/%{name}-4.0/sqlite_specs*.xml

%files sqlite-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libgda-sqlite-4.0.pc

%files sqlcipher
%defattr(-,root,root,-)
%{_libdir}/%{name}-4.0/providers/%{name}-sqlcipher.so
%{_datadir}/%{name}-4.0/sqlcipher_specs*.xml

%files sqlcipher-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libgda-sqlcipher-4.0.pc

%files web
%defattr(-,root,root,-)
%{_libdir}/%{name}-4.0/providers/%{name}-web.so
%{_datadir}/%{name}-4.0/php/*
%{_datadir}/%{name}-4.0/web/*
%{_datadir}/%{name}-4.0/web_specs*.xml

%files web-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/%{name}-web-4.0.pc

%if %{MYSQL}
%files mysql
%defattr(-,root,root,-)
%{_libdir}/libgda-4.0/providers/libgda-mysql.so
%{_datadir}/%{name}-4.0/mysql_specs*.xml

%files mysql-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libgda-mysql-4.0.pc
%endif

%if %{POSTGRES}
%files postgres
%defattr(-,root,root,-)
%{_libdir}/libgda-4.0/providers/libgda-postgres.so
%{_datadir}/%{name}-4.0/postgres_specs*.xml

%files postgres-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libgda-postgres-4.0.pc
%endif

%if %{MDB}
%files mdb
%defattr(-,root,root,-)
%{_libdir}/libgda-4.0/providers/libgda-mdb.so
%{_datadir}/%{name}-4.0/mdb_specs*.xml

%files mdb-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libgda-mdb-4.0.pc
%endif

%if %{JAVA}
%files java
%defattr(-,root,root)
%{_libdir}/libgda-4.0/providers/libgda-jdbc.so
%{_libdir}/libgda-4.0/providers/gdaprovider-4.0.jar
%{_datadir}/%{name}-4.0/jdbc_specs*.xml

%files java-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/libgda-jdbc-4.0.pc
%endif


%changelog
* Sun Apr 10 2011 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.2.5-1
- upstream 4.2.5

* Wed Mar 23 2011 Dan Horák <dan@danny.cz> - 1:4.2.4-3
- rebuilt for mysql 5.5.10 (soname bump in libmysqlclient)

* Tue Feb 22 2011 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.2.4-2
- fix sqlite loading (RHBZ #673809)

* Thu Feb 17 2011 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.2.4-1
- upstream 4.2.4

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:4.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan  8 2011  <builder@zangetsu.seireitei> - 1:4.2.2-2
- drop sqlite patch: should be fixed in latest xulrunner package

* Tue Nov 30 2010 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.2.2-1
- Upstream 4.2.2
- Cleaned spec from deprecated providers support
- Fix sqlite3 shared library loading (RHBZ #658471)

* Tue Oct 26 2010 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.2.0-1
- Update to upstream 4.2.0
- New provider: sqlcipher (SQLite encryption extension)
- New patch fixing 4.2.0 build issue
- Disable GObject introspection since it's broken

* Wed Jun 16 2010 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.1.6-1
- Update to upstream 4.1.6
- Add new BR: gnome-doc-utils
- Dropped BR: gir-repository

* Tue Apr 27 2010 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.1.4-1
- Update to upstream 4.1.4 (required by Glom)
- Added web provider and ui subpackages
- Added new BR (gtk2, unique, goocanvas, graphviz) for libgda-ui

* Thu Apr 22 2010 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.0.8-2
- add gir descriptions files

* Thu Apr 22 2010 Haïkel Guémar <hguemar@fedoraproject.org> - 1:4.0.8-1
- Update to upstream 4.0.8

* Thu Feb 18 2010 Denis Leroy <denis@poolshark.org> - 1:4.0.7-1
- Update to upstream 4.0.7

* Mon Jan 18 2010 Denis Leroy <denis@poolshark.org> - 1:4.0.6-1
- Update to upstream 4.0.6
- Added Java JDBC provider subpackage

* Sat Nov  7 2009 Denis Leroy <denis@poolshark.org> - 1:4.0.5-1
- Update to upstream 4.0.5
- Source URL fix

* Tue Sep 15 2009 Denis Leroy <denis@poolshark.org> - 1:4.0.4-1
- Update to upstream version 4.0.4

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 1:4.0.2-3
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:4.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jun 25 2009 Denis Leroy <denis@poolshark.org> - 1:4.0.2-1
- Update to upstream 4.0.2
- Use system sqlite library

* Mon Mar 23 2009  <denis@poolshark.org> - 1:4.0.0-1
- Update to upstream 4.0.0

* Wed Mar  4 2009 Denis Leroy <denis@poolshark.org> - 1:3.99.12-1
- Update to upstream 3.99.12

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:3.99.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Feb 14 2009 Denis Leroy <denis@poolshark.org> - 1:3.99.11-1
- Update to 3.99.11 (many bug fixes)

* Fri Jan 16 2009 Denis Leroy <denis@poolshark.org> - 1:3.99.8-1
- Switch to 4.0 ABI
- Update to upstream 3.99.8
- Patch updates (upstreamed and ported)
- Added JAVA package flag, currently disabled

* Mon Oct 27 2008 Denis Leroy <denis@poolshark.org> - 1:3.1.2-6
- Added patch to fix providers path on x86_64 (#468510)

* Thu Jul 10 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1:3.1.2-5
- Rebuild against new db4-4.7

* Tue Jun 17 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.1.2-4
- Rebuild against new freetds

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1:3.1.2-3
- Autorebuild for GCC 4.3

* Sat Jan 26 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.1.2-2
- Rebuid now that the system sqlite has column metadata enabled, so that we
  use the system version instead of our own private copy (bz 430258)

* Fri Jan 25 2008 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.1.2-1
- New upstream release 3.1.2 (needed for new gnumeric)
- Drop upstreamed / no longer needed patches

* Thu Dec 06 2007 Release Engineering <rel-eng at fedoraproject dot org> - 3.0.1-6
- Rebuild for deps

* Sun Oct 21 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.0.1-5
- Rebuild to fix untranslated strings on x86_64 in
  /usr/share/libgda-3.0/sqlite_specs_drop_index.xml
  which caused multilib problems (bz 342101)

* Fri Aug 17 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.0.1-4
- Fix building on ppc64 again (patch configure not configure.in, now we are
  no longer running autoconf)

* Wed Aug 15 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.0.1-3
- Enable microsoft access (mdb) support now that mdbtools is in Fedora
- Enable xBase (dBase, Clipper, FoxPro) support, it seems that xbase has been
  available for quite a while now
- Switch from using mysqlclient10 to using mysql-libs for the msql provider

* Wed Aug  8 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.0.1-2
- Build against system sqlite instead of own private copy (this is possible now
  that the system sqlite is of a high enough version)
- Enable FreeTDS provider (FreeTDS is in Fedora now)
- Update License tag for new Licensing Guidelines compliance

* Sun May 27 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 1:3.0.1-1
- New upstream release 3.0.1
- Remove mono bindings sub-package as upstream no longer includes them

* Thu May 10 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-12
- Don't build mono/sharp bits on ppc64
- Fixup packaging of sharp bindings to match the mono packaging guidelines

* Fri Dec 15 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-11
- Rebuild for new postgres

* Mon Aug 28 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-10
- FE6 Rebuild

* Tue Jun 20 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-9
- Add BuildRequires: libtool hopefully _really_ fixing building with the new
  stripped mock config. (Drop BR: autoconf which is implied by BR: automake).

* Thu Jun 15 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-8
- Add BuildRequires: automake, autoconf to fix building with the new even more
  stripped mock config.

* Sat Jun 10 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-7
- Add BuildRequires: gettext, bison, flex, gamin-devel to fix building with
  new stripped mock config.

* Thu May 11 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-6
- Move Obsoletes and Provides for plugins out of the plugins %%description,
  so that they actually Obsolete and Provide instead of showing up in rpm -qi
  (bug 191213).

* Thu May  4 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-5
- Add patch3 fixing a couple of x86_64 bugs (bz 190366)

* Mon Feb 13 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-4
- Bump release and rebuild for new gcc4.1 and glibc.
- Make sqlite plugin use system sqlite not build in version
- Make sqlite plugin a seperate package again
- Attempt to properly install C-sharp/mono bindings
- Add %%{?dist} for consistency with my other packages
- Remove static lib from -devel package

* Tue Jan 17 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-3
- Make -sharp package Require the main package.

* Mon Jan 16 2006 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-2
- Remove unneeded requires (.so reqs are automaticly picked up by rpm).
- Add BuildRequires for building libgda-sharp

* Sun Nov 27 2005 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.9.100-1
- New upstream version
- Drop 4 intergrated patches
- Removed sqlite configurability, it is now an internal part of the upstream
  sources.

* Fri Aug  5 2005 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.2.0-8
- Remove libgda.la file from devel package.

* Sat Jun 25 2005 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.2.0-7
- Added Patch4: libgda-1.2.0-libdir.patch which fixes loading of
  database providers on platforms with a lib64 dir. Thanks to:
  Bas Driessen <bas.driessen@xobas.com> for the patch.
- Enabled building of libgda-ldap and libgda-sqlite by default.

* Tue Jun 21 2005 Hans de Goede <j.w.r.degoede@hhs.nl> 1:1.2.0-6
- rebuild so that we depend on the proper version of libpq.so (#160917)
- change names of database providers from gda-xxx to libgda-xxx (#160917)

* Wed Mar  2 2005 Caolan McNamara <caolanm@redhat.com> 1:1.2.0-5
- rebuild with gcc4

* Fri Feb 11 2005 Caolan McNamara <caolanm@redhat.com> 1:1.2.0-4
- well, that was moronic

* Wed Feb 10 2005 Caolan McNamara <caolanm@redhat.com> 1:1.2.0-3
- bandaid

* Wed Feb  9 2005 Jeremy Katz <katzj@redhat.com> - 1:1.2.0-2
- rebuild to try to fix broken dep

* Fri Feb 4 2005 Caolan McNamara <caolanm@redhat.com> 1:1.2.0-1
- bump to latest version
- drop integrated break warning patch
- update configure patch

* Wed Jan 12 2005 Tim Waugh <twaugh@redhat.com> 1:1.0.4-5
- Rebuilt for new readline.

* Sat Oct 30 2004 Caolan McNamara <caolanm@redhat.com> 1:1.0.4-4
- Use mysqlclient10

* Fri Oct  8 2004 Caolan McNamara <caolanm@redhat.com> 1:1.0.4-3
- #rh135043# Extra BuildRequires

* Thu Sep  9 2004 Bill Nottingham <notting@redhat.com> 1:1.0.4-2
- %%defattr

* Thu Aug 12 2004 Caolan McNamara <caolanm@redhat.com> 1:1.0.4-1
- Initial Red Hat import
- patch for missing break statement
- fixup devel package requirement pickiness
- autoconf patch to pick up correct mysql path from mysql_config (e.g. x64)
- autoconf patch to just look in the normal place for postgres first

* Tue Mar 11 2003 David Hollis <dhollis@davehollis.com>
- Fix --with-tds & --without-tds to match what configure wants

* Tue Jan 28 2003 Yanko Kaneti <yaneti@declera.com>
- Remove the idl path
- Include gda-config man page
- add --without-* for disabled providers
- package and use the omf/scrollkeeper bits

* Tue Dec 31 2002 David Hollis <dhollis@davehollis.com>
- Added sqlite-devel buildreq
- Include gda-config-tool man page

* Mon Aug 19 2002 Ben Liblit <liblit@acm.org>
- Fixed version number substitutions

- Removed some explicit "Requires:" prerequisites that RPM will figure
  out on its own.  Removed explicit dependency on older MySQL client
  libraries

- Required that the ODBC development package be installed if we are
  building the ODBC provider

- Created distinct subpackages for each provider, conditional on that
  provider actually being enabled; some of these will need to be
  updated as the family of available providers changes

- Updated files list to match what "make install" actually installs

- Added URL tag pointing to GNOME-DB project's web site

* Tue Feb 26 2002 Chris Chabot <chabotc@reviewboard.com>
- Added defines and configure flags for all supported DB types

* Mon Feb 25 2002 Chris Chabot <chabotc@reviewboard.com>
- Cleaned up formatting
- Added Requirements
- Added defines for postgres, mysql, odbc support

* Thu Feb 21 2002 Chris Chabot <chabotc@reviewboard.com>
- Initial spec file
